import { Http } from '@zeedhi/core';

export class GraphicsController {
  public fillGraphicPie({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const seriesNameColumn = props.seriesNameColumn;
    const labelsNameColumn = props.labelsNameColumn;
    const sendObject = {
      filter: [],
    };
    
    if (props.idOrigem) {
      sendObject.filter.push(
        {
          name: 'IDORIGEM',
          operator: '=',
          value: props.idOrigem,
        },
      );
    }
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
      const data = response.data.dataset[routeName];
      const newLabels = [];
      const newSeries = [];
      data.forEach((row) => { newLabels.push(row[labelsNameColumn]); newSeries.push(row[seriesNameColumn]); });
      component.series = newSeries;
      const options = {
        labels: newLabels,
      };
      component.updateChart(options);
    });
  }
  
  public fillGraphicBar({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const xaxisNameColumn = props.xaxisNameColumn;
    const seriesProps = props.series;
    const sendObject = {
      filter: [],
    };
    
    if (props.idOrigem) {
      sendObject.filter.push(
        {
          name: 'IDORIGEM',
          operator: '=',
          value: props.idOrigem,
        },
      );
    }
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
      const data = response.data.dataset[routeName];
      const xaxis = [];
      const newSeries = [];
      Object.keys(seriesProps).forEach((prop) => {
        newSeries.push({
          name: seriesProps[prop].label,
          data: data.map((item) => item[prop]),
        });
      });
      
      data.forEach((row) => { xaxis.push(row[xaxisNameColumn]); });
      component.series = newSeries;
      const options = {
        xaxis: {
          categories: xaxis,
        },
      };
      component.updateChart(options);
    });
  }
}
